@@ -19,9 +19,29 @@ from majormode.perseus.model.obj import Object
 
 
 class AdminService(BaseService):
+    class AuthenticationFailureException(BaseService.BaseServiceException):
+        """
+        Signal that the email address or password that has been provided for
+        authenticating a user account is incorrect.
+        """
+        pass
+
+    class ContactAlreadyUsedException(BaseService.BaseServiceException):
+        """
+        Signal that one or more contact information such as, for instance, an
+        email address, provided to sign-up a user account, is already used by
+        another user account of the platform.
+        """
+        pass
+
     BaseService._declare_custom_exceptions({
+        'AuthenticationFailureException': AuthenticationFailureException,
+        'ContactAlreadyUsedException': ContactAlreadyUsedException,
     })
 
+    def __init__(self, session):
+        super().__init__(session)
+
     def sign_in(
             self,
             identifier,
